@@ -1,7 +1,10 @@
 use pipebuilder_common::{
     api::{
         client::ApiClient,
-        models::{ActivateNodeRequest, DeactivateNodeRequest, ListNodeStateRequest, NodeState},
+        models::{
+            ActivateNodeRequest, DeactivateNodeRequest, ListNodeStateRequest, NodeState,
+            ShutdownNodeRequest,
+        },
     },
     NodeRole, Result,
 };
@@ -25,3 +28,9 @@ pub(crate) async fn deactivate_node(client: &ApiClient, role: NodeRole, id: Stri
     let _ = client.deactivate_node(&request).await?;
     Ok(())
 }
+
+pub(crate) async fn shutdown_node(client: &ApiClient, role: NodeRole, id: String) -> Result<()> {
+    let request = ShutdownNodeRequest { role, id };
+    let _ = client.shutdown_node(&request).await?;
+    Ok(())
+}
